+++
title = "Lastmod not suppressed as the suppress period is 0.0"
description = """
  `lastmod` front-matter parameter is **not** suppressed in this post as
  `org-hugo-suppress-lastmod-period` is 0.0 (default).
  """
date = 2100-12-21
lastmod = 2100-12-21T00:00:00+00:00
tags = ["suppress", "lastmod", "zero", "autoset"]
draft = false
+++

`org-hugo-suppress-lastmod-period` is set to **0.0** seconds in Local
Variables.

_For tests, the "current date" is always Dec 21, 2100._
